@@ -2,6 +2,7 @@ import re
 import json
 from docopt import docopt
 from localstack import config
+from localstack.utils.common import truncate, format_bytes
 from localstack_ext import constants as ext_constants
 from localstack_ext.bootstrap import licensing
 
@@ -19,11 +20,11 @@ Options:
     auth = import_auth()
 
     try:
-        provider = args['--provider'] or 'github'
+        provider = args['--provider'] or 'internal'
         auth.login(provider, args['--username'])
-        print('Successfully logged in via provider: %s' % provider)
+        print('Successfully logged in')
     except Exception as e:
-        print('Authentication error: %s' % e)
+        raise Exception('Authentication error: %s' % e)
 
 
 def cmd_ci(argv, args):
@@ -113,6 +114,32 @@ Commands:
         local_daemon.kill_servers()
 
 
+def cmd_pod(argv, args):
+    """
+Usage:
+  localstack pod <subcommand> [ <name> ]
+
+Commands:
+  push <name>      Push the state of a local cloud pod
+  pull <name>      Pull the state to launch a cloud pod locally
+    """
+    args.update(docopt(cmd_pod.__doc__.strip(), argv=argv))
+    from localstack_ext.bootstrap import pods_client  # leave import here to avoid dependency conflict
+
+    if args['<subcommand>'] == 'push':
+        print('Pushing local persistence state to server ...')
+        pods_client.push_state(args['<name>'], args)
+    elif args['<subcommand>'] == 'pull':
+        print('Pulling persistence state from server ...')
+        pods_client.pull_state(args['<name>'], args)
+    elif args['<subcommand>'] == 'list':
+        print('Fetching list of pods from server ...')
+        result = pods_client.list_pods(args)
+        # print('result', result)
+        headers = {'pod_name': 'Name', 'backend': 'Backend', 'url': 'URL', 'size': 'Size', 'state': 'State'}
+        print_table(result, headers=headers, formats={'size': format_bytes})
+
+
 def cmd_status(argv, args):
     from localstack.utils.cli import print_status
     print_status()
@@ -129,9 +156,23 @@ def register_commands():
         'parameters': [],
         'function': cmd_daemons
     }
+    config.CLI_COMMANDS['pod'] = {
+        'description': 'Manage state of local cloud pods',
+        'parameters': [],
+        'function': cmd_pod
+    }
     if 'status' in config.CLI_COMMANDS:
         config.CLI_COMMANDS['status']['function'] = cmd_status
 
+    config.CLI_COMMANDS['login'] = {
+        'description': 'Log in using an external OAuth provider (e.g., Github)',
+        'function': cmd_login
+    }
+    config.CLI_COMMANDS['logout'] = {
+        'description': 'Log out and delete any session tokens',
+        'function': cmd_logout
+    }
+
     # TODO enable commands below?
     return
 
@@ -141,14 +182,6 @@ def register_commands():
         'parameters': [],
         'function': cmd_config
     }
-    config.CLI_COMMANDS['login'] = {
-        'description': 'Log in using an external OAuth provider (e.g., Github)',
-        'function': cmd_login
-    }
-    config.CLI_COMMANDS['logout'] = {
-        'description': 'Log out and delete any session tokens',
-        'function': cmd_logout
-    }
     config.CLI_COMMANDS['ci'] = {
         'description': 'Manage continuous integration repositories and settings',
         'function': cmd_ci
@@ -188,3 +221,39 @@ def get_params(args, names=[], mandatory=True):
     if len(result) == 1:
         return result[0]
     return result
+
+
+def print_table(data_list, headers=[], formats={}):
+    from tabulate import tabulate
+    if not isinstance(data_list, list):
+        raise Exception('Non-list input cannot be rendered as table: %s' % data_list)
+    formats = formats or {}
+    data_list = [i if isinstance(i, dict) else {'value': i} for i in data_list]
+    # prepare headers
+    if isinstance(headers, dict):
+        headers = [{'key': k, 'name': v} for k, v in headers.items()]
+    # build column metadata
+    columns = headers
+    if not columns:
+        columns = []
+        for row in data_list:
+            for key in row.keys():
+                if key not in columns:
+                    columns.append(key)
+    for idx in range(len(columns)):
+        column = columns[idx]
+        columns[idx] = column if isinstance(column, dict) else {'key': column, 'name': column}
+
+    # build rows
+    def _format(row, key):
+        value = row.get(key)
+        formatter = formats.get(key)
+        if formatter:
+            return formatter(value)
+        if not value:
+            return value
+        return truncate(str(value), max_length=30)
+    rows = [[_format(row, h['key']) for h in columns] for row in data_list]
+    headers = [col['name'] for col in columns]
+    result = tabulate(rows, headers=headers)
+    print(result)
