@@ -1,6 +1,6 @@
 import os
-yrpho=Exception
-yrphm=hasattr
+wIvFf=Exception
+wIvFL=hasattr
 from localstack import config
 from localstack.utils.aws import aws_stack
 from localstack.dashboard import infra as dashboard_infra
@@ -14,7 +14,7 @@ def get_resources(fetch_func):
   result=[]
   fetch_func(result)
   return result
- except yrpho:
+ except wIvFf:
   pass
  return[]
 def get_rds_databases(name_filter,pool,env):
@@ -100,7 +100,7 @@ def get_codecommit_repos(name_filter,pool,env):
 def get_graph(*args,**kwargs):
  os.environ['AWS_ACCESS_KEY_ID']=os.environ.get('AWS_ACCESS_KEY_ID')or 'foobar'
  os.environ['AWS_SECRET_ACCESS_KEY']=os.environ.get('AWS_SECRET_ACCESS_KEY')or 'foobar'
- if yrphm(THREAD_LOCAL,'request_context'):
+ if wIvFL(THREAD_LOCAL,'request_context'):
   region=kwargs.get('region')or config.DEFAULT_REGION
   THREAD_LOCAL.request_context.headers[MARKER_APIGW_REQUEST_REGION]=region
  result=run_safe(get_graph_orig,*args,**kwargs)or{'nodes':[],'edges':[]}
