@@ -1,10 +1,10 @@
 import os
-QoOrx=True
-QoOrs=dict
-QoOrE=open
-QoOrc=False
-QoOrR=Exception
-QoOrb=int
+FslUH=True
+FslUR=dict
+FslUN=open
+FslUn=False
+FslUf=Exception
+FslUJ=int
 import sys
 import glob
 import json
@@ -25,14 +25,14 @@ ROOT_USER=('root','pass123')
 FTP_USER_DEFAULT_PASSWD='12345'
 FTP_USER_PERMISSIONS='elradfmwMT'
 FTP_PASSIVE_PORTS=[ext_config.SERVICE_INSTANCES_PORTS_END-2,ext_config.SERVICE_INSTANCES_PORTS_END-1,ext_config.SERVICE_INSTANCES_PORTS_END]
-USE_SUBPROCESS=QoOrx
+USE_SUBPROCESS=FslUH
 DIRECTORY_MAPPING={}
 DIRECTORY_MAPPING_FILE='<data_dir>/ftp.user.dir.mapping.json'
 def get_dir_mapping_key(username,server_port):
  return '{}:{}'.format(username,server_port)
 def apply_patches():
  extended_proto_cmds=TLS_FTPHandler.proto_cmds.copy()
- extended_proto_cmds.update({'SITE ADDUSER':QoOrs(perm='m',auth=QoOrx,arg=QoOrx,help='Syntax: SITE <SP> ADDUSER USERNAME PASSWORD HOME PRIVS <SP>.')})
+ extended_proto_cmds.update({'SITE ADDUSER':FslUR(perm='m',auth=FslUH,arg=FslUH,help='Syntax: SITE <SP> ADDUSER USERNAME PASSWORD HOME PRIVS <SP>.')})
  def _on_file_received(self,file_path):
   key=get_dir_mapping_key(self.username,self.server.address[1])
   mapping=get_directory_mapping()
@@ -42,7 +42,7 @@ def apply_patches():
   bucket=configuration['HomeDirectory']
   user_dir=configuration['UserDirectory']
   key=file_path.replace('{}/'.format(user_dir),'')
-  with QoOrE(file_path)as f:
+  with FslUN(file_path)as f:
    s3_client=aws_stack.connect_to_service('s3')
    s3_client.put_object(Bucket=bucket,Key=key,Body=f.read())
    LOG.info('Received file via FTP -- target: s3://{}/{}'.format(bucket,key))
@@ -83,16 +83,16 @@ def start_ftp(port):
    pythonpath+=':%s'%':'.join(paths)
   env_vars={'SERVICES':services,'PYTHONPATH':pythonpath}
   cmd='%s %s %s'%(sys.executable,__file__,port)
-  thread=ShellCommandThread(cmd,outfile=subprocess.PIPE,env_vars=env_vars,quiet=QoOrc)
+  thread=ShellCommandThread(cmd,outfile=subprocess.PIPE,env_vars=env_vars,quiet=FslUn)
   thread.start()
   time.sleep(2)
  else:
-  thread=do_start_ftp(port,asynchronous=QoOrx)
+  thread=do_start_ftp(port,asynchronous=FslUH)
  time.sleep(2)
  wait_for_port_open(port,retries=10,sleep_time=1.5)
  TMP_THREADS.append(thread)
  return thread
-def do_start_ftp(port,asynchronous=QoOrx):
+def do_start_ftp(port,asynchronous=FslUH):
  LOG.info('Starting (S)FTP server on port %s...'%port)
  apply_patches()
  authorizer=DummyAuthorizer()
@@ -110,7 +110,7 @@ def do_start_ftp(port,asynchronous=QoOrx):
   try:
    server=FTPServer(('0.0.0.0',port),handler)
    server.serve_forever()
-  except QoOrR as e:
+  except FslUf as e:
    LOG.info('Unable to run FTP server on port %s: %s'%(port,e))
    raise
  if asynchronous:
@@ -134,7 +134,7 @@ def set_directory_mapping(key,value):
 def get_directory_mapping_file():
  return DIRECTORY_MAPPING_FILE.replace('<data_dir>',localstack_config.TMP_FOLDER)
 def main():
- do_start_ftp(QoOrb(sys.argv[1]),asynchronous=QoOrc)
+ do_start_ftp(FslUJ(sys.argv[1]),asynchronous=FslUn)
 if __name__=='__main__':
  main()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
