@@ -1,15 +1,15 @@
 #!/usr/bin/env python
-YrqzE=None
-Yrqzw=True
-Yrqzi=Exception
-Yrqzn=str
-YrqzR=len
-Yrqzd=isinstance
-YrqzF=dict
-Yrqzl=hasattr
-Yrqzf=int
-Yrqzg=False
-YrqzO=bytes
+qrsGt=None
+qrsGp=True
+qrsGL=Exception
+qrsGW=str
+qrsGA=len
+qrsGe=isinstance
+qrsGP=dict
+qrsGI=hasattr
+qrsGQ=int
+qrsGi=False
+qrsGE=bytes
 import os
 import sys
 import json
@@ -39,32 +39,32 @@ USED_BIND_ADDRESSES=[]
 MAC_NETWORK_INTERFACE='en0'
 BUCKET_MARKER_LOCAL='__local__'
 class FuncThread(threading.Thread):
- def __init__(self,func,params=YrqzE):
+ def __init__(self,func,params=qrsGt):
   threading.Thread.__init__(self)
-  self.daemon=Yrqzw
+  self.daemon=qrsGp
   self.params=params
   self.func=func
  def run(self):
   try:
    self.func(self.params)
-  except Yrqzi as e:
+  except qrsGL as e:
    log('Error in thread function: %s %s'%(e,traceback.format_exc()))
 class ThreadedHTTPServer(ThreadingMixIn,HTTPServer):
- daemon_threads=Yrqzw
+ daemon_threads=qrsGp
 class RequestHandler(BaseHTTPRequestHandler):
  def do_POST(self):
   self.read_content()
   try:
    result=self.handle_request()
    self.send_response(200)
-  except Yrqzi as e:
-   error_string=Yrqzn(e)
+  except qrsGL as e:
+   error_string=qrsGW(e)
    result=json.dumps({'error':error_string})
    log('Error handling request: %s - %s'%(self.request_json,e))
    self.send_response(500)
-  self.send_header('Content-Length','%s'%YrqzR(result)if result else 0)
+  self.send_header('Content-Length','%s'%qrsGA(result)if result else 0)
   self.end_headers()
-  if YrqzR(result or ''):
+  if qrsGA(result or ''):
    self.wfile.write(to_bytes(result))
  def handle_request(self):
   request=self.request_json
@@ -84,17 +84,17 @@ class RequestHandler(BaseHTTPRequestHandler):
    os._exit(0)
   else:
    result={'error':'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if Yrqzd(result,YrqzF)else result
+  result=json.dumps(result)if qrsGe(result,qrsGP)else result
   return result
  def read_content(self):
-  if Yrqzl(self,'data_bytes'):
+  if qrsGI(self,'data_bytes'):
    return
   content_length=self.headers.get('Content-Length')
-  self.data_bytes=self.rfile.read(Yrqzf(content_length))
+  self.data_bytes=self.rfile.read(qrsGQ(content_length))
   self.request_json={}
   try:
    self.request_json=json.loads(self.data_bytes)
-  except Yrqzi:
+  except qrsGL:
    pass
 class RequestHandlerRoot(RequestHandler):
  def handle_request(self):
@@ -108,13 +108,13 @@ class RequestHandlerRoot(RequestHandler):
    os._exit(0)
   else:
    result={'error':'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if Yrqzd(result,YrqzF)else result
+  result=json.dumps(result)if qrsGe(result,qrsGP)else result
   return result
 def s3_download(request):
  bucket=request['bucket']
  key=request['key']
  tmp_dir=os.environ.get('TMPDIR')or tempfile.mkdtemp()
- target_file=os.path.join(tmp_dir,request.get('file_name')or 's3file.%s'%Yrqzn(uuid.uuid4()))
+ target_file=os.path.join(tmp_dir,request.get('file_name')or 's3file.%s'%qrsGW(uuid.uuid4()))
  if not os.path.exists(target_file)or request.get('overwrite'):
   if bucket==BUCKET_MARKER_LOCAL:
    shutil.copy(key,target_file)
@@ -133,14 +133,14 @@ def start_ssh_forward_proxy(options):
   sys.path.append(path)
  from tcp_proxy import server_loop
  port=options.get('port')or get_free_tcp_port()
- host=LOCAL_BIND_ADDRESS_PATTERN.replace('*',Yrqzn(YrqzR(USED_BIND_ADDRESSES)+2))
+ host=LOCAL_BIND_ADDRESS_PATTERN.replace('*',qrsGW(qrsGA(USED_BIND_ADDRESSES)+2))
  create_network_interface_alias(host)
  USED_BIND_ADDRESSES.append(host)
  log('Starting local SSH forward proxy, %s:22 -> localhost:%s'%(host,port))
  options={'bind_port':22,'bind_addr':host,'port':port}
  FuncThread(server_loop,options).start()
  return{'host':host,'forward_port':port}
-def create_network_interface_alias(address,interface=YrqzE):
+def create_network_interface_alias(address,interface=qrsGt):
  sudo_cmd='sudo'
  if is_mac_os():
   interface=interface or MAC_NETWORK_INTERFACE
@@ -157,16 +157,16 @@ def create_network_interface_alias(address,interface=YrqzE):
     assert interface not in['lo']and not iface_addr.startswith('127.')
     run_cmd('{sudo_cmd} ifconfig {iface}:0 {addr} netmask 255.255.255.0 up'.format(sudo_cmd=sudo_cmd,addr=address,iface=interface))
     return
-   except Yrqzi as e:
+   except qrsGL as e:
     log('Unable to create forward proxy on interface %s, address %s: %s'%(interface,address,e))
     pass
- raise Yrqzi('Unable to create network interface')
+ raise qrsGL('Unable to create network interface')
 def run_shell_cmd(command):
  try:
   return{'result':run_cmd(command)}
- except Yrqzi as e:
-  error_string=Yrqzn(e)
-  if Yrqzd(e,subprocess.CalledProcessError):
+ except qrsGL as e:
+  error_string=qrsGW(e)
+  if qrsGe(e,subprocess.CalledProcessError):
    error_string='%s: %s'%(error_string,e.output)
   return{'error':error_string}
 def get_os():
@@ -177,22 +177,22 @@ def get_os():
  return 'windows'
 def run_cmd(cmd):
  log('Running command: %s'%cmd)
- return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=Yrqzw))
+ return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=qrsGp))
 def log(*args):
  print(*args)
  sys.stdout.flush()
 def is_mac_os():
  try:
-  out=to_str(subprocess.check_output('uname -a',shell=Yrqzw))
+  out=to_str(subprocess.check_output('uname -a',shell=qrsGp))
   return 'Darwin' in out
  except subprocess.CalledProcessError:
-  return Yrqzg
+  return qrsGi
 def is_linux():
  try:
-  out=to_str(subprocess.check_output('uname -a',shell=Yrqzw))
+  out=to_str(subprocess.check_output('uname -a',shell=qrsGp))
   return 'Linux' in out
  except subprocess.CalledProcessError:
-  return Yrqzg
+  return qrsGi
 def get_ip_address(ifname):
  s=socket.socket(socket.AF_INET,socket.SOCK_DGRAM)
  return socket.inet_ntoa(fcntl.ioctl(s.fileno(),0x8915,struct.pack('256s',to_bytes(ifname[:15])))[20:24])
@@ -203,29 +203,29 @@ def get_free_tcp_port():
  tcp.close()
  return port
 def to_bytes(obj):
- return obj.encode('utf-8')if Yrqzd(obj,Yrqzn)else obj
+ return obj.encode('utf-8')if qrsGe(obj,qrsGW)else obj
 def to_str(obj):
- return obj.decode('utf-8')if Yrqzd(obj,YrqzO)else obj
+ return obj.decode('utf-8')if qrsGe(obj,qrsGE)else obj
 def start_server(port,handler):
  kill_server(port)
  try:
   log('Starting local daemon server on port %s'%port)
   httpd=ThreadedHTTPServer(('0.0.0.0',port),handler)
   httpd.serve_forever()
- except Yrqzi:
+ except qrsGL:
   log('Local daemon server already running, or port %s not available'%port)
   pass
 def kill_server(port):
  try:
   requests.post('http://localhost:%s'%port,data='{"op":"kill"}')
- except Yrqzi:
+ except qrsGL:
   pass
 def kill_servers():
  kill_server(DEFAULT_PORT_LOCAL_DAEMON)
  kill_server(DEFAULT_PORT_LOCAL_DAEMON_ROOT)
 def main():
  logging.basicConfig()
- daemon_type=sys.argv[1]if YrqzR(sys.argv)>1 else 'main'
+ daemon_type=sys.argv[1]if qrsGA(sys.argv)>1 else 'main'
  os.environ['AWS_ACCESS_KEY_ID']=os.environ.get('AWS_ACCESS_KEY_ID')or 'test'
  os.environ['AWS_SECRET_ACCESS_KEY']=os.environ.get('AWS_SECRET_ACCESS_KEY')or 'test'
  if daemon_type=='main':
@@ -241,12 +241,12 @@ def start_in_background():
  LOG.info('Logging local daemon output to %s'%log_file)
  python_cmd=sys.executable
  cmd='%s %s'%(python_cmd,__file__)
- run(cmd,outfile=log_file,asynchronous=Yrqzw)
+ run(cmd,outfile=log_file,asynchronous=qrsGp)
  LOG.info('Attempting to obtain sudo privileges for local daemon of EC2 API '+'(required to start SSH forward proxy on privileged port 22). '+'You may be asked for your sudo password.')
- run('sudo ls',stdin=Yrqzw)
+ run('sudo ls',stdin=qrsGp)
  def start_root_daemon(*args):
   cmd='sudo %s %s root >> %s'%(python_cmd,__file__,log_file)
-  run(cmd,outfile=log_file,stdin=Yrqzw)
+  run(cmd,outfile=log_file,stdin=qrsGp)
  FuncThread(start_root_daemon).start()
 if __name__=='__main__':
  main()
