@@ -1,13 +1,13 @@
 import os
-EqPIR=object
-EqPIY=None
-EqPIK=Exception
-EqPIx=set
-EqPIn=property
-EqPIz=classmethod
-EqPIB=False
-EqPIX=True
-EqPIs=getattr
+aEDPU=object
+aEDPV=None
+aEDPC=Exception
+aEDPT=set
+aEDPh=property
+aEDPm=classmethod
+aEDPy=False
+aEDPA=True
+aEDPG=getattr
 import re
 import json
 import logging
@@ -22,18 +22,18 @@ from localstack.utils.common import(load_file,to_str,to_bytes,mkdir,save_file,cp
 from localstack_ext.utils import auth
 LOG=logging.getLogger(__name__)
 PERISTED_FOLDERS=['api_states','dynamodb','kinesis']
-class CloudPodManager(EqPIR):
+class CloudPodManager(aEDPU):
  BACKEND='_none_'
  CONFIG_FILE='.localstack.yml'
- def __init__(self,pod_name=EqPIY,config=EqPIY):
+ def __init__(self,pod_name=aEDPV,config=aEDPV):
   self.pod_name=pod_name
   self.config=config
  def push(self):
-  raise EqPIK('Not implemented')
+  raise aEDPC('Not implemented')
  def pull(self):
-  raise EqPIK('Not implemented')
+  raise aEDPC('Not implemented')
  def get_pod_size(self):
-  raise EqPIK('Not implemented')
+  raise aEDPC('Not implemented')
  def restart_container(self):
   LOG.info('Restarting LocalStack instance with updated persistence state - this may take some time ...')
   data={'action':'restart'}
@@ -47,29 +47,29 @@ class CloudPodManager(EqPIR):
    response=requests.get(url)
    content=json.loads(to_str(response.content))
    statuses=[v for k,v in content['services'].items()]
-   assert EqPIx(statuses)==EqPIx(['running'])
+   assert aEDPT(statuses)==aEDPT(['running'])
   retry(check_status,sleep=3,retries=10)
- @EqPIn
+ @aEDPh
  def pod_config(self):
   return self.config.get('pods',{}).get(self.pod_name)
- @EqPIz
- def get(cls,pod_name,config=EqPIY):
+ @aEDPm
+ def get(cls,pod_name,config=aEDPV):
   config=config or CloudPodManager.load_config()
   pod_config=_pod_config(pod_name,config=config)
   backend=pod_config.get('backend')
   for clazz in cls.__subclasses__():
    if clazz.BACKEND==backend:
     return clazz(pod_name=pod_name,config=config)
-  raise EqPIK('Unable to find Cloud Pod manager implementation type "%s"'%backend)
- @EqPIz
- def load_config(cls,safe=EqPIB):
+  raise aEDPC('Unable to find Cloud Pod manager implementation type "%s"'%backend)
+ @aEDPm
+ def load_config(cls,safe=aEDPy):
   try:
    return yaml.load(to_str(load_file(cls.CONFIG_FILE)))
-  except EqPIK:
+  except aEDPC:
    if safe:
     return{}
-   raise EqPIK('Unable to find and parse config file "%s"'%cls.CONFIG_FILE)
- @EqPIz
+   raise aEDPC('Unable to find and parse config file "%s"'%cls.CONFIG_FILE)
+ @aEDPm
  def data_dir(cls):
   if not config.DATA_DIR:
    try:
@@ -81,10 +81,10 @@ class CloudPodManager(EqPIR):
     data_dir_host=[m for m in mounts if m['Destination']==data_dir_env][0]['Source']
     data_dir_host=re.sub(r'^(/host_mnt)?',r'',data_dir_host)
     config.DATA_DIR=data_dir_host
-   except EqPIK:
+   except aEDPC:
     LOG.warning('''Unable to determine DATA_DIR from LocalStack Docker container - please make sure $MAIN_CONTAINER_NAME is configured properly''')
   if not config.DATA_DIR:
-   raise EqPIK('Working with local cloud pods requires $DATA_DIR configuration')
+   raise aEDPC('Working with local cloud pods requires $DATA_DIR configuration')
   return config.DATA_DIR
 class CloudPodManagerGit(CloudPodManager):
  BACKEND='git'
@@ -95,9 +95,9 @@ class CloudPodManagerGit(CloudPodManager):
   remote_location=self.pod_config.get('url')
   try:
    porcelain.pull(repo,remote_location,refspecs=branch)
-  except EqPIK as e:
+  except aEDPC as e:
    LOG.info('Unable to pull repo: %s'%e)
-  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==EqPIx([b'HEAD'])
+  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==aEDPT([b'HEAD'])
   if is_empty_repo:
    LOG.debug('Initializing empty repository %s'%self.clone_dir)
    init_file=os.path.join(self.clone_dir,'.init')
@@ -105,7 +105,7 @@ class CloudPodManagerGit(CloudPodManager):
    porcelain.add(repo,init_file)
    porcelain.commit(repo,message='Initial commit')
   if branch not in repo:
-   porcelain.branch_create(repo,branch,force=EqPIX)
+   porcelain.branch_create(repo,branch,force=aEDPA)
   self.switch_branch(branch)
   for folder in PERISTED_FOLDERS:
    LOG.info('Copying persistence folder %s to local git repo %s'%(folder,self.clone_dir))
@@ -126,7 +126,7 @@ class CloudPodManagerGit(CloudPodManager):
   branch=self.pod_config.get('branch')
   remote_ref=b'refs/heads/%s'%to_bytes(branch)
   if remote_ref not in remote_refs:
-   raise EqPIK('Unable to find branch "%s" in remote git repo'%branch)
+   raise aEDPC('Unable to find branch "%s" in remote git repo'%branch)
   remote_location=self.pod_config.get('url')
   self.switch_branch(branch)
   branch_ref=b'refs/heads/%s'%to_bytes(branch)
@@ -144,7 +144,7 @@ class CloudPodManagerGit(CloudPodManager):
   client,path=get_transport_and_path_from_url(self.pod_config.get('url'))
   return client,path
  def local_repo(self):
-  self.clone_dir=EqPIs(self,'clone_dir',EqPIY)
+  self.clone_dir=aEDPG(self,'clone_dir',aEDPV)
   if not self.clone_dir:
    pod_dir_name=re.sub(r'(\s|/)+','',self.pod_name)
    self.clone_dir=os.path.join(config.TMP_FOLDER,'pods',pod_dir_name,'repo')
@@ -179,7 +179,7 @@ def store_pod_metadata(pod_name,metadata):
  response=safe_requests.post('%s/cloudpods'%API_ENDPOINT,json.dumps(metadata),headers=auth_headers)
  content=response.content
  if response.status_code>=400:
-  raise EqPIK('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
+  raise aEDPC('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
  return json.loads(to_str(content))
 def list_pods(args):
  result=[]
@@ -187,19 +187,19 @@ def list_pods(args):
  response=safe_requests.get('%s/cloudpods'%API_ENDPOINT,headers=auth_headers)
  content=response.content
  if response.status_code>=400:
-  raise EqPIK('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
+  raise aEDPC('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
  remote_pods=json.loads(to_str(content)).get('cloudpods',[])
  remote_pods=[{'state':'Shared',**pod}for pod in remote_pods]
  result.extend(remote_pods)
- local_pods=CloudPodManager.load_config(safe=EqPIX).get('pods',{})
+ local_pods=CloudPodManager.load_config(safe=aEDPA).get('pods',{})
  local_pods=[{'pod_name':k,'state':'Local Only',**v}for k,v in local_pods.items()]
- existing_names=EqPIx([pod['pod_name']for pod in result])
+ existing_names=aEDPT([pod['pod_name']for pod in result])
  result.extend([pod for pod in local_pods if pod['pod_name']not in existing_names])
  return result
-def _pod_config(pod_name,config=EqPIY):
+def _pod_config(pod_name,config=aEDPV):
  config=config or CloudPodManager.load_config()
  pod_config=config.get('pods',{}).get(pod_name)
  if not pod_config:
-  raise EqPIK('Unable to find config for pod named "%s"'%pod_name)
+  raise aEDPC('Unable to find config for pod named "%s"'%pod_name)
  return pod_config
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
