@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-yLXfG=dict
-yLXfJ=super
-yLXfs=hasattr
-yLXfT=Exception
-yLXfD=object
-yLXfW=dir
-yLXfz=None
-yLXfK=False
-yLXfN=True
-yLXfh=len
-yLXfB=set
+UcwTR=dict
+UcwTv=super
+UcwTM=hasattr
+UcwTQ=Exception
+UcwTW=object
+UcwTa=dir
+UcwTr=None
+UcwTu=False
+UcwTk=True
+UcwTF=len
+UcwTn=set
 import errno
 import socket
 from select import select
 from socket import(AF_INET,AF_INET6,SOCK_STREAM,IPV6_V6ONLY,SO_REUSEADDR,IPPROTO_TCP,IPPROTO_IPV6,TCP_NODELAY,SOL_SOCKET)
-class AttrDict(yLXfG):
+class AttrDict(UcwTR):
  def __init__(self,*args,**kwargs):
-  yLXfJ(AttrDict,self).__init__(*args,**kwargs)
+  UcwTv(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and yLXfs(socket,'IPV6_V6ONLY'):
+ if six and UcwTM(socket,'IPV6_V6ONLY'):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +37,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except yLXfT:
+ except UcwTQ:
   pass
-class Server(yLXfD):
+class Server(UcwTW):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +51,17 @@ class Server(yLXfD):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(yLXfD):
- def __init__(self,opt,sock,addr,yLXfW):
+class Half(UcwTW):
+ def __init__(self,opt,sock,addr,UcwTa):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.yLXfW=yLXfW
-  self.name='peer' if self.yLXfW else 'client'
+  self.UcwTa=UcwTa
+  self.name='peer' if self.UcwTa else 'client'
   self.queue=[]
-  self.dest=yLXfz
-  self.err=yLXfz
-  self.ready=yLXfK
+  self.dest=UcwTr
+  self.err=UcwTr
+  self.ready=UcwTu
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,7 +72,7 @@ class Half(yLXfD):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=yLXfN
+   self.ready=UcwTk
    self.copy()
   return self.err
  def error(self,msg,e):
@@ -81,9 +81,9 @@ class Half(yLXfD):
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except yLXfT as e:
+  except UcwTQ as e:
    return self.error('send error',e)
-  if n!=yLXfh(self.queue[0]):
+  if n!=UcwTF(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,17 +92,17 @@ class Half(yLXfD):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=yLXfK
+    self.ready=UcwTu
     return
    return self.error('recv socket error',e)
-  except yLXfT as e:
+  except UcwTQ as e:
    return self.error('recv error',e)
-  if yLXfh(buf)==0:
+  if UcwTF(buf)==0:
    return self.error('eof',0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(yLXfD):
+class Proxy(UcwTW):
  def __init__(self,opt,sock,addr):
   self.opt=opt
   self.cl=Half(opt,sock,addr,'i')
@@ -110,7 +110,7 @@ class Proxy(yLXfD):
   self.peer=Half(opt,peer,addr,'o')
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=yLXfz
+  self.err=UcwTr
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -125,7 +125,7 @@ class Proxy(yLXfD):
   return self.err
 def server_loop(opt):
  qs=[]
- opt['ip6']=opt.get('ip6',yLXfK)
+ opt['ip6']=opt.get('ip6',UcwTu)
  opt['bind_addr']=opt.get('bind_addr','0.0.0.0')
  opt['addr']=opt.get('addr','127.0.0.1')
  opt['bind_port']=opt.get('bind_port',0)
@@ -137,15 +137,15 @@ def server_loop(opt):
    q.pre_wait(rr,r,w,e)
   timeo=10.0 if not rr else 0.0
   r,w,e=select(r,w,e,timeo)
-  r=yLXfB(r).union(rr)
+  r=UcwTn(r).union(rr)
   for q in qs:
    if q.post_wait(r,w,e):
     qs.remove(q)
 def main():
- opt={'ip6':yLXfK,'bind_port':2223,'addr':'192.168.43.191','port':22}
- opt={'ip6':yLXfK,'bind_port':48429,'addr':'128.0.100.3','port':22}
- opt={'ip6':yLXfK,'port':54237,'bind_addr':'128.0.100.2','bind_port':22}
- opt={'ip6':yLXfK,'port':54237,'bind_addr':'192.168.100.3','bind_port':22}
+ opt={'ip6':UcwTu,'bind_port':2223,'addr':'192.168.43.191','port':22}
+ opt={'ip6':UcwTu,'bind_port':48429,'addr':'128.0.100.3','port':22}
+ opt={'ip6':UcwTu,'port':54237,'bind_addr':'128.0.100.2','bind_port':22}
+ opt={'ip6':UcwTu,'port':54237,'bind_addr':'192.168.100.3','bind_port':22}
  server_loop(opt)
 if __name__=='__main__':
  main()
