@@ -1,11 +1,11 @@
 import os
-BefDc=Exception
-BefDH=any
-BefDu=str
-BefDJ=None
-BefDY=False
-BefDI=bool
-BefDm=True
+rNKBS=Exception
+rNKBn=any
+rNKBd=str
+rNKBX=None
+rNKBo=False
+rNKBi=bool
+rNKBP=True
 import logging
 from localstack import config as localstack_config
 from localstack.utils import common
@@ -29,14 +29,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except BefDc:
+  except rNKBS:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled('ec2'):
     local_daemon.start_in_background()
-  except BefDc as e:
+  except rNKBS as e:
    LOG.warning('Unable to start local daemon process: %s'%e)
   if is_api_key_configured:
    port=localstack_config.EDGE_PORT
@@ -64,7 +64,7 @@ def register_localstack_plugins():
    docker_flags+=['-p {a}:{p}:{p}'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols='udp'):
    docker_flags+=['-p {a}:{p}:{p}/udp'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if BefDH([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if rNKBn([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=['-p {start}-{end}:{start}-{end}'.format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled('eks'):
   kube_config=os.path.expanduser('~/.kube/config')
@@ -180,24 +180,24 @@ def load_plugin_files():
   aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except BefDc as e:
-  if 'No module named' not in BefDu(e):
+ except rNKBS as e:
+  if 'No module named' not in rNKBd(e):
    print(e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except BefDc:
-  start_metadata_service=BefDJ
+ except rNKBS:
+  start_metadata_service=rNKBX
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except BefDc:
+   except rNKBS:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=BefDY
+   config_ext.ENFORCE_IAM=rNKBo
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -220,9 +220,9 @@ def _setup_logging():
  logging.getLogger('root').setLevel(logging.WARNING)
  logging.getLogger('').setLevel(logging.WARNING)
 def api_key_configured():
- return BefDI(os.environ.get('LOCALSTACK_API_KEY'))
+ return rNKBi(os.environ.get('LOCALSTACK_API_KEY'))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return BefDm
+ return rNKBP
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
